"use strict";

/*
  Returns the array of plugins (config) for
  the NelityCMS config passed. 🚀
*/
const path = require('path');

const dirName = process.cwd();

const createPluginPaths = (config = {
  collections: []
}, {
  mdxOptions = {}
} = {}) => {
  let plugins = [];

  if (config.media_folder) {
    plugins.push({
      resolve: "gatsby-source-filesystem",
      options: {
        name: `media_folder`,
        path: path.join(`${dirName}`, `${config.media_folder}/`)
      }
    });
  }

  config.collections.forEach(collection => {
    if (collection.name) {
      if (collection.folder) {
        if (collection.extension === 'mdx') {
          plugins.push({
            resolve: "gatsby-plugin-mdx",
            options: mdxOptions
          });
        }

        const name = `${collection.name}`;
        plugins.push({
          resolve: "gatsby-source-filesystem",
          options: {
            name,
            path: path.join(`${dirName}`, `${collection.folder}/`)
          }
        });
      } else {
        collection.files.forEach(file => {
          if (file.name && file.file) {
            const name = `${collection.name}_${file.name}`;
            plugins.push({
              resolve: "gatsby-source-filesystem",
              options: {
                name,
                path: path.join(`${dirName}`, `${file.file}`)
              }
            });
          }
        });
      }
    }
  });
  return plugins;
};

module.exports = createPluginPaths;